California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance Activity Propositions & Ballot Measures
Election Cycle: 2021 through 2022 Historical 2019 through 2020 2017 through 2018 2015 through 2016 2013 through 2014 2011 through 2012 2009 through 2010 2007 through 2008 2005 through 2006 2003 through 2004 2001 through 2002 1999 through 2000
All of the campaign committees that have organized to support or oppose propositions and ballot measures on California's statewide ballot are available here. Click below on the proposition or ballot measure to learn who is involved in the campaign to win your vote on Election Day.
Prior Elections
NOVEMBER 2, 2010, GENERAL
9 Measures
PROPOSITION 019 - CHANGES CALIFORNIA LAW TO LEGALIZE MARIJUANA AND ALLOW IT TO BE REGULATED AND TAXED.
PROPOSITION 020 - REDISTRICTING OF CONGRESSIONAL DISTRICTS.
PROPOSITION 021 - ESTABLISHES $18 ANNUAL VEHICLE LICENSE SURCHARGE TO HELP FUND STATE PARKS AND WILDLIFE PROGRAMS AND GRANTS FREE ADMISSION TO ALL STATE PARKS TO SURCHARGED VEHICLES.
PROPOSITION 022 - PROHIBITS THE STATE FROM TAKING FUNDS USED FOR TRANSPORTATION OR LOCAL GOVERNMENT PROJECTS AND SERVICES.
PROPOSITION 023 - SUSPENDS AIR POLLUTION CONTROL LAWS REQUIRING MAJOR POLLUTERS TO REPORT AND REDUCE GREENHOUSE GAS EMISSIONS THAT CAUSE GLOBAL WARMING UNTIL UNEMPLOYMENT DROPS BELOW SPECIFIED LEVEL
PROPOSITION 024 - REPEALS RECENT LEGISLATION THAT WOULD ALLOW BUSINESSES TO CARRY BACK LOSSES, SHARE TAX CREDITS, AND USE A SALES-BASED INCOME CALCULATION TO LOWER TAXABLE INCOME.
PROPOSITION 025 - CHANGES LEGISLATIVE VOTE REQUIREMENT TO PASS A BUDGET FROM TWO-THIRDS TO A SIMPLE MAJORITY. RETAINS TWO-THIRDS VOTE REQUIREMENT FOR TAXES.
PROPOSITION 026 - INCREASES LEGISLATIVE VOTE REQUIREMENT TO TWO-THIRDS FOR STATE LEVIES & CHARGES. IMPOSES ADDITIONAL REQUIREMENT FOR VOTERS TO APPROVE LOCAL LEVIES & CHARGES WITH LIMITED EXCEPTIONS.
PROPOSITION 027 - ELIMINATES STATE COMMISSION ON REDISTRICTING. CONSOLIDATES AUTHORITY FOR REDISTRICTING WITH ELECTED REPRESENTATIVES.
JUNE 8, 2010, PRIMARY
5 Measures
PROPOSITION 013 - PROPERTY TAX: NEW CONSTRUCTION EXCLUSION: SEISMIC RETROFITTING.
PROPOSITION 014 - ELECTIONS: OPEN PRIMARIES.
PROPOSITION 015 - POLITICAL REFORM ACT OF 1974: CALIFORNIA FAIR ELECTIONS ACT OF 2008.
PROPOSITION 016 - NEW TWO-THIRDS VOTE REQUIREMENT FOR LOCAL PUBLIC ELECTRICITY PROVIDERS.
PROPOSITION 017 - ALLOWS AUTO INSURANCE COMPANIES TO BASE THEIR PRICES IN PART ON A DRIVER'S HISTORY OF INSURANCE COVERAGE.
MAY 19, 2009, SPECIAL ELECTION
6 Measures
PROPOSITION 001A - STATE BUDGET. CHANGES CALIFORNIA BUDGET PROCESS. LIMITS STATE SPENDING. INCREASES "RAINY DAY " BUDGET STABILIZATION FUND.
PROPOSITION 001B - EDUCATION FUNDING. PAYMENT PLAN.
PROPOSITION 001C - LOTTERY MODERNIZATION ACT.
PROPOSITION 001D - PROTECTS CHILDREN'S SERVICES FUNDING. HELPS BALANCE STATE BUDGET.
PROPOSITION 001E - MENTAL HEALTH SERVICES FUNDING. TEMPORARY REALLOCATION. HELPS BALANCE STATE BUDGET.
PROPOSITION 001F - ELECTED OFFICIALS' SALARIES. PREVENTS PAY INCREASES DURING BUDGET DEFICIT YEARS.